"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextProperties = void 0;
const util_1 = require("../util");
const FontVariant_1 = require("./FontVariant");
const TextTransformation_1 = require("./TextTransformation");
const Typeface_1 = require("./Typeface");
/**
 * This class represents the style of some text.
 *
 * @extends ITextProperties
 * @since 0.4.0
 * @private
 */
class TextProperties {
    /**
     * Constructor.
     *
     * @since 0.4.0
     */
    constructor() {
        this.fontSize = 12;
        this.fontVariant = FontVariant_1.FontVariant.Normal;
        this.transformation = TextTransformation_1.TextTransformation.None;
        this.typeface = Typeface_1.Typeface.Normal;
    }
    /** @inheritDoc */
    setBackgroundColor(color) {
        this.backgroundColor = color;
    }
    /** @inheritDoc */
    getBackgroundColor() {
        return this.backgroundColor;
    }
    /** @inheritDoc */
    setColor(color) {
        this.color = color;
    }
    /** @inheritDoc */
    getColor() {
        return this.color;
    }
    /** @inheritDoc */
    setFontName(name) {
        this.fontName = name;
    }
    /** @inheritDoc */
    getFontName() {
        return this.fontName;
    }
    /** @inheritDoc */
    setFontSize(size) {
        if (util_1.isPositiveLength(size)) {
            this.fontSize = size;
        }
    }
    /** @inheritDoc */
    getFontSize() {
        return this.fontSize;
    }
    /** @inheritDoc */
    setFontVariant(fontVariant) {
        this.fontVariant = fontVariant;
    }
    /** @inheritDoc */
    getFontVariant() {
        return this.fontVariant;
    }
    /** @inheritDoc */
    setTextTransformation(transformation) {
        this.transformation = transformation;
    }
    /** @inheritDoc */
    getTextTransformation() {
        return this.transformation;
    }
    /** @inheritDoc */
    setTypeface(typeface) {
        this.typeface = typeface;
    }
    /** @inheritDoc */
    getTypeface() {
        return this.typeface;
    }
}
exports.TextProperties = TextProperties;
