import { OdfElement } from '../OdfElement';
import { Heading } from './Heading';
import { List } from './List';
import { Paragraph } from './Paragraph';
/**
 * This class represents an item in a list.
 *
 * @example
 * const listItem = new ListItem();
 * listItem.addHeading('headline');
 * listItem.addParagraph('paragraph');
 * const subList = listItem.addList();
 *
 * @since 0.2.0
 */
export declare class ListItem extends OdfElement {
    /**
     * Creates a `ListItem` instance that represents an item in a list.
     *
     * @example
     * new ListItem();
     *
     * @since 0.2.0
     */
    constructor();
    /**
     * Adds a heading at the end of the list item.
     * If a text is given, this will be set as text content of the heading.
     *
     * @param {string} [text] The text content of the heading
     * @param {number} [level=1] The heading level; defaults to 1 if omitted
     * @returns {Heading} The newly added heading
     * @since 0.11.0
     */
    addHeading(text?: string, level?: number): Heading;
    /**
     * Adds an empty list at the end of the list item.
     *
     * @example
     * new ListItem()
     *   .addList();
     *
     * @returns {List} The newly added list
     * @since 0.11.0
     */
    addList(): List;
    /**
     * Adds a paragraph at the end of the list item.
     * If a text is given, this will be set as text content of the paragraph.
     *
     * @param {string} [text] The text content of the paragraph
     * @returns {Paragraph} The newly added paragraph
     * @since 0.11.0
     */
    addParagraph(text?: string): Paragraph;
}
