"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListLevelStyleVisitor = void 0;
const OdfElementName_1 = require("../OdfElementName");
const OdfAttributeName_1 = require("../OdfAttributeName");
class ListLevelStyleVisitor {
    visit(listLevelStyle, document, parent) {
        const listLevelStyleElement = document.createElement(OdfElementName_1.OdfElementName.TextListLevelStyleBullet);
        parent.appendChild(listLevelStyleElement);
        listLevelStyleElement.setAttribute(OdfAttributeName_1.OdfAttributeName.TextLevel, `${listLevelStyle.getLevel()}`);
        listLevelStyleElement.setAttribute(OdfAttributeName_1.OdfAttributeName.TextBulletChar, listLevelStyle.getBulletChar());
        const numberPrefix = listLevelStyle.getNumberPrefix();
        if (numberPrefix !== undefined) {
            listLevelStyleElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleNumPrefix, numberPrefix);
        }
        const numberSuffix = listLevelStyle.getNumberSuffix();
        if (numberSuffix !== undefined) {
            listLevelStyleElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleNumSuffix, numberSuffix);
        }
        const relativeBulletSize = listLevelStyle.getRelativeBulletSize();
        if (relativeBulletSize !== undefined) {
            listLevelStyleElement.setAttribute(OdfAttributeName_1.OdfAttributeName.TextBulletRelativeSize, relativeBulletSize);
        }
        this.setListLevelProperties(listLevelStyle, document, listLevelStyleElement);
        return listLevelStyleElement;
    }
    setListLevelProperties(listLevelStyle, document, parent) {
        const listLevelPropertiesElement = document.createElement(OdfElementName_1.OdfElementName.StyleListLevelProperties);
        parent.appendChild(listLevelPropertiesElement);
        listLevelPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.TextListLevelPositionAndSpaceMode, listLevelStyle.getListLevelPositionAndSpaceMode());
        const listLevelLabelAlignmentElement = document.createElement(OdfElementName_1.OdfElementName.StyleListLevelLabelAlignment);
        listLevelPropertiesElement.appendChild(listLevelLabelAlignmentElement);
        listLevelLabelAlignmentElement.setAttribute(OdfAttributeName_1.OdfAttributeName.TextLabelFollowedBy, listLevelStyle.getLabelFollowedBy());
        const tabStopPosition = listLevelStyle.getListTabStopPosition();
        if (tabStopPosition !== undefined) {
            listLevelLabelAlignmentElement.setAttribute(OdfAttributeName_1.OdfAttributeName.TextListTabStopPosition, `${tabStopPosition}mm`);
        }
        const textIndent = listLevelStyle.getTextIndent();
        if (textIndent !== undefined) {
            listLevelLabelAlignmentElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatTextIndent, `${textIndent}mm`);
        }
        const marginLeft = listLevelStyle.getMarginLeft();
        if (marginLeft !== undefined) {
            listLevelLabelAlignmentElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatMarginLeft, `${marginLeft}mm`);
        }
    }
}
exports.ListLevelStyleVisitor = ListLevelStyleVisitor;
