"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextPropertiesVisitor = void 0;
const style_1 = require("../../api/style");
const OdfAttributeName_1 = require("../OdfAttributeName");
const OdfElementName_1 = require("../OdfElementName");
class TextPropertiesVisitor {
    visit(textProperties, document, parent) {
        const textPropertiesElement = document.createElement(OdfElementName_1.OdfElementName.StyleTextProperties);
        parent.appendChild(textPropertiesElement);
        const fontVariant = textProperties.getFontVariant();
        if (fontVariant !== style_1.FontVariant.Normal) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatFontVariant, fontVariant);
        }
        const textTransformation = textProperties.getTextTransformation();
        if (textTransformation !== style_1.TextTransformation.None) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatTextTransform, textTransformation);
        }
        const color = textProperties.getColor();
        if (color !== undefined) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatColor, color.toHex());
        }
        const fontName = textProperties.getFontName();
        if (fontName !== undefined) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleFontName, fontName);
        }
        const fontSize = textProperties.getFontSize();
        if (fontSize !== 12) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatFontSize, fontSize + 'pt');
        }
        const typeface = textProperties.getTypeface();
        if (typeface === style_1.Typeface.Italic || typeface === style_1.Typeface.BoldItalic) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatFontStyle, 'italic');
        }
        if (typeface === style_1.Typeface.Oblique || typeface === style_1.Typeface.BoldOblique) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatFontStyle, 'oblique');
        }
        if (typeface === style_1.Typeface.Bold ||
            typeface === style_1.Typeface.BoldItalic ||
            typeface === style_1.Typeface.BoldOblique) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatFontWeight, 'bold');
        }
        const backgroundColor = textProperties.getBackgroundColor();
        if (backgroundColor !== undefined &&
            !(textProperties instanceof style_1.ParagraphStyle)) {
            textPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBackgroundColor, backgroundColor.toHex());
        }
        return textPropertiesElement;
    }
}
exports.TextPropertiesVisitor = TextPropertiesVisitor;
